@@ -1,6 +1,5 @@
-from mindsdb_sql import ParsingException
 from mindsdb_sql.parser.ast.base import ASTNode
-from mindsdb_sql.utils import indent
+from mindsdb_sql.parser.utils import indent
 
 
 class CommonTableExpression(ASTNode):
