@@ -36,7 +36,7 @@ class SQLLexer(Lexer):
         UNION, ALL,
 
         # DML
-        INSERT, INTO, VALUES,
+        INSERT, DELETE, INTO, VALUES,
 
         # Special
         DOT, COMMA, LPAREN, RPAREN, PARAMETER,
@@ -139,6 +139,7 @@ class SQLLexer(Lexer):
 
     # DML
     INSERT = r'\bINSERT\b'
+    DELETE = r'\bDELETE\b'
     INTO = r'\bINTO\b'
     VALUES = r'\bVALUES\b'
 
